@@ -1,11 +1,5 @@
 from .calculate_metrics import evaluate_metrics
-from .wer import wer, wer_for_evaluate
 from .cer import cer, cer_for_evaluate
+from .wer import wer, wer_for_evaluate
 
-__all__=[
-    'evaluate_metrics',
-    'wer',
-    'cer',
-    'wer_for_evaluate',
-    'cer_for_evaluate'
-]
\ No newline at end of file
+__all__ = ["evaluate_metrics", "wer", "cer", "wer_for_evaluate", "cer_for_evaluate"]
